[![Docs](https://github.com/rouskinlab/seismograph/actions/workflows/documentation.yml/badge.svg)](https://github.com/rouskinlab/seismograph/actions/workflows/documentation.yml)

# Seismograph

A python library for the analysis of SEISMIC data.

## Installation

```
pip install seismograph
```

## Documentation

The documentation is available on [Github Pages](https://rouskinlab.github.io/seismograph).

## Contributors

Yves Martin, Casper L'espérance-Kerckhoff
